pub struct CreateAIWorkloadConfigFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to CreateAIWorkloadConfig.
Creates a reusable AI workload configuration that defines datasets, data sources, and benchmark tool settings for consistent performance testing of generative AI inference deployments on Amazon SageMaker AI.
Implementations
Sourceimpl CreateAIWorkloadConfigFluentBuilder
impl CreateAIWorkloadConfigFluentBuilder
Sourcepub fn as_input(&self) -> &CreateAiWorkloadConfigInputBuilder
pub fn as_input(&self) -> &CreateAiWorkloadConfigInputBuilder
Access the CreateAIWorkloadConfig as a reference.
Sourcepub async fn send(
self,
) -> Result<CreateAiWorkloadConfigOutput, SdkError<CreateAIWorkloadConfigError, HttpResponse>>
pub async fn send( self, ) -> Result<CreateAiWorkloadConfigOutput, SdkError<CreateAIWorkloadConfigError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<CreateAiWorkloadConfigOutput, CreateAIWorkloadConfigError, Self>
pub fn customize( self, ) -> CustomizableOperation<CreateAiWorkloadConfigOutput, CreateAIWorkloadConfigError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn ai_workload_config_name(self, input: impl Into<String>) -> Self
pub fn ai_workload_config_name(self, input: impl Into<String>) -> Self
The name of the AI workload configuration. The name must be unique within your Amazon Web Services account in the current Amazon Web Services Region.
Sourcepub fn set_ai_workload_config_name(self, input: Option<String>) -> Self
pub fn set_ai_workload_config_name(self, input: Option<String>) -> Self
The name of the AI workload configuration. The name must be unique within your Amazon Web Services account in the current Amazon Web Services Region.
Sourcepub fn get_ai_workload_config_name(&self) -> &Option<String>
pub fn get_ai_workload_config_name(&self) -> &Option<String>
The name of the AI workload configuration. The name must be unique within your Amazon Web Services account in the current Amazon Web Services Region.
Sourcepub fn dataset_config(self, input: AiDatasetConfig) -> Self
pub fn dataset_config(self, input: AiDatasetConfig) -> Self
The dataset configuration for the workload. Specify input data channels with their data sources for benchmark workloads.
Sourcepub fn set_dataset_config(self, input: Option<AiDatasetConfig>) -> Self
pub fn set_dataset_config(self, input: Option<AiDatasetConfig>) -> Self
The dataset configuration for the workload. Specify input data channels with their data sources for benchmark workloads.
Sourcepub fn get_dataset_config(&self) -> &Option<AiDatasetConfig>
pub fn get_dataset_config(&self) -> &Option<AiDatasetConfig>
The dataset configuration for the workload. Specify input data channels with their data sources for benchmark workloads.
Sourcepub fn ai_workload_configs(self, input: AiWorkloadConfigs) -> Self
pub fn ai_workload_configs(self, input: AiWorkloadConfigs) -> Self
The benchmark tool configuration and workload specification. Provide the specification as an inline YAML or JSON string.
Sourcepub fn set_ai_workload_configs(self, input: Option<AiWorkloadConfigs>) -> Self
pub fn set_ai_workload_configs(self, input: Option<AiWorkloadConfigs>) -> Self
The benchmark tool configuration and workload specification. Provide the specification as an inline YAML or JSON string.
Sourcepub fn get_ai_workload_configs(&self) -> &Option<AiWorkloadConfigs>
pub fn get_ai_workload_configs(&self) -> &Option<AiWorkloadConfigs>
The benchmark tool configuration and workload specification. Provide the specification as an inline YAML or JSON string.
Appends an item to Tags.
To override the contents of this collection use set_tags.
The metadata that you apply to Amazon Web Services resources to help you categorize and organize them. Each tag consists of a key and a value, both of which you define. For more information, see Tagging Amazon Web Services Resources in the Amazon Web Services General Reference.
The metadata that you apply to Amazon Web Services resources to help you categorize and organize them. Each tag consists of a key and a value, both of which you define. For more information, see Tagging Amazon Web Services Resources in the Amazon Web Services General Reference.
The metadata that you apply to Amazon Web Services resources to help you categorize and organize them. Each tag consists of a key and a value, both of which you define. For more information, see Tagging Amazon Web Services Resources in the Amazon Web Services General Reference.