#[non_exhaustive]pub struct ExtendTrainingPlanOutput {
pub training_plan_extensions: Option<Vec<TrainingPlanExtension>>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.training_plan_extensions: Option<Vec<TrainingPlanExtension>>The list of extensions for the training plan, including the newly created extension.
Implementations
Sourceimpl ExtendTrainingPlanOutput
impl ExtendTrainingPlanOutput
Sourcepub fn training_plan_extensions(&self) -> &[TrainingPlanExtension]
pub fn training_plan_extensions(&self) -> &[TrainingPlanExtension]
The list of extensions for the training plan, including the newly created extension.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .training_plan_extensions.is_none().
Sourceimpl ExtendTrainingPlanOutput
impl ExtendTrainingPlanOutput
Sourcepub fn builder() -> ExtendTrainingPlanOutputBuilder
pub fn builder() -> ExtendTrainingPlanOutputBuilder
Creates a new builder-style object to manufacture ExtendTrainingPlanOutput.