#[non_exhaustive]pub struct InferenceComponentSchedulingConfigBuilder { /* private fields */ }Expand description
A builder for InferenceComponentSchedulingConfig.
Implementations
Sourceimpl InferenceComponentSchedulingConfigBuilder
impl InferenceComponentSchedulingConfigBuilder
Sourcepub fn placement_strategy(
self,
input: InferenceComponentPlacementStrategy,
) -> Self
pub fn placement_strategy( self, input: InferenceComponentPlacementStrategy, ) -> Self
The strategy for placing inference component copies across available instances. If you also set AvailabilityZoneBalance, this strategy applies to placement within each Availability Zone.
- SPREAD
-
Distributes copies evenly across available instances for better resilience.
- BINPACK
-
Packs copies onto fewer instances to optimize resource utilization.
Sourcepub fn set_placement_strategy(
self,
input: Option<InferenceComponentPlacementStrategy>,
) -> Self
pub fn set_placement_strategy( self, input: Option<InferenceComponentPlacementStrategy>, ) -> Self
The strategy for placing inference component copies across available instances. If you also set AvailabilityZoneBalance, this strategy applies to placement within each Availability Zone.
- SPREAD
-
Distributes copies evenly across available instances for better resilience.
- BINPACK
-
Packs copies onto fewer instances to optimize resource utilization.
Sourcepub fn get_placement_strategy(
&self,
) -> &Option<InferenceComponentPlacementStrategy>
pub fn get_placement_strategy( &self, ) -> &Option<InferenceComponentPlacementStrategy>
The strategy for placing inference component copies across available instances. If you also set AvailabilityZoneBalance, this strategy applies to placement within each Availability Zone.
- SPREAD
-
Distributes copies evenly across available instances for better resilience.
- BINPACK
-
Packs copies onto fewer instances to optimize resource utilization.
Sourcepub fn availability_zone_balance(
self,
input: InferenceComponentAvailabilityZoneBalance,
) -> Self
pub fn availability_zone_balance( self, input: InferenceComponentAvailabilityZoneBalance, ) -> Self
Configuration for balancing inference component copies across Availability Zones.
Sourcepub fn set_availability_zone_balance(
self,
input: Option<InferenceComponentAvailabilityZoneBalance>,
) -> Self
pub fn set_availability_zone_balance( self, input: Option<InferenceComponentAvailabilityZoneBalance>, ) -> Self
Configuration for balancing inference component copies across Availability Zones.
Sourcepub fn get_availability_zone_balance(
&self,
) -> &Option<InferenceComponentAvailabilityZoneBalance>
pub fn get_availability_zone_balance( &self, ) -> &Option<InferenceComponentAvailabilityZoneBalance>
Configuration for balancing inference component copies across Availability Zones.
Sourcepub fn build(self) -> InferenceComponentSchedulingConfig
pub fn build(self) -> InferenceComponentSchedulingConfig
Consumes the builder and constructs a InferenceComponentSchedulingConfig.