#[non_exhaustive]pub enum AiDatasetConfig {
InputDataConfig(Vec<AiWorkloadInputDataConfig>),
#[non_exhaustive] Unknown,
}Expand description
The dataset configuration for an AI workload. This is a union type — specify one of the members.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
InputDataConfig(Vec<AiWorkloadInputDataConfig>)
An array of input data channel configurations for the workload.
#[non_exhaustive]Unknown
The Unknown variant represents cases where new union variant was received. Consider upgrading the SDK to the latest available version.
An unknown enum variant
Note: If you encounter this error, consider upgrading your SDK to the latest version.
The Unknown variant represents cases where the server sent a value that wasn’t recognized
by the client. This can happen when the server adds new functionality, but the client has not been updated.
To investigate this, consider turning on debug logging to print the raw HTTP response.
Implementations
Sourceimpl AiDatasetConfig
impl AiDatasetConfig
Sourcepub fn as_input_data_config(
&self,
) -> Result<&Vec<AiWorkloadInputDataConfig>, &Self>
pub fn as_input_data_config( &self, ) -> Result<&Vec<AiWorkloadInputDataConfig>, &Self>
Tries to convert the enum instance into InputDataConfig, extracting the inner Vec.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_input_data_config(&self) -> bool
pub fn is_input_data_config(&self) -> bool
Returns true if this is a InputDataConfig.
Sourcepub fn is_unknown(&self) -> bool
pub fn is_unknown(&self) -> bool
Returns true if the enum instance is the Unknown variant.