#[non_exhaustive]pub struct ContainerMetricsConfig {
pub metrics_endpoints: Option<Vec<MetricsEndpoint>>,
}Expand description
The configuration for container-level metrics scraping. Use this configuration to specify a custom metrics endpoint path and publishing frequency for container metrics. When EnableDetailedObservability is set to True in MetricsConfig, metrics are scraped from the container's Prometheus endpoint. If this configuration is not provided, the default path /metrics on port 8080 is used with a default publishing frequency of 60 seconds. For first-party and Deep Learning Containers (DLC), the endpoint path is determined automatically and this configuration is optional.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.metrics_endpoints: Option<Vec<MetricsEndpoint>>A list of metrics endpoints to scrape from the container. Each endpoint specifies the path where the container exposes Prometheus-formatted metrics and the frequency at which to publish them. You can specify a maximum of 1 endpoint.
Implementations
Sourceimpl ContainerMetricsConfig
impl ContainerMetricsConfig
Sourcepub fn metrics_endpoints(&self) -> &[MetricsEndpoint]
pub fn metrics_endpoints(&self) -> &[MetricsEndpoint]
A list of metrics endpoints to scrape from the container. Each endpoint specifies the path where the container exposes Prometheus-formatted metrics and the frequency at which to publish them. You can specify a maximum of 1 endpoint.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .metrics_endpoints.is_none().
Sourceimpl ContainerMetricsConfig
impl ContainerMetricsConfig
Sourcepub fn builder() -> ContainerMetricsConfigBuilder
pub fn builder() -> ContainerMetricsConfigBuilder
Creates a new builder-style object to manufacture ContainerMetricsConfig.