#[non_exhaustive]pub struct InferenceComponentSchedulingConfig {
pub placement_strategy: Option<InferenceComponentPlacementStrategy>,
pub availability_zone_balance: Option<InferenceComponentAvailabilityZoneBalance>,
}Expand description
The scheduling configuration that determines how inference component copies are placed across available instances when copies are added or removed.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.placement_strategy: Option<InferenceComponentPlacementStrategy>The strategy for placing inference component copies across available instances. If you also set AvailabilityZoneBalance, this strategy applies to placement within each Availability Zone.
- SPREAD
-
Distributes copies evenly across available instances for better resilience.
- BINPACK
-
Packs copies onto fewer instances to optimize resource utilization.
availability_zone_balance: Option<InferenceComponentAvailabilityZoneBalance>Configuration for balancing inference component copies across Availability Zones.
Implementations
Sourceimpl InferenceComponentSchedulingConfig
impl InferenceComponentSchedulingConfig
Sourcepub fn placement_strategy(&self) -> Option<&InferenceComponentPlacementStrategy>
pub fn placement_strategy(&self) -> Option<&InferenceComponentPlacementStrategy>
The strategy for placing inference component copies across available instances. If you also set AvailabilityZoneBalance, this strategy applies to placement within each Availability Zone.
- SPREAD
-
Distributes copies evenly across available instances for better resilience.
- BINPACK
-
Packs copies onto fewer instances to optimize resource utilization.
Sourcepub fn availability_zone_balance(
&self,
) -> Option<&InferenceComponentAvailabilityZoneBalance>
pub fn availability_zone_balance( &self, ) -> Option<&InferenceComponentAvailabilityZoneBalance>
Configuration for balancing inference component copies across Availability Zones.
Sourceimpl InferenceComponentSchedulingConfig
impl InferenceComponentSchedulingConfig
Sourcepub fn builder() -> InferenceComponentSchedulingConfigBuilder
pub fn builder() -> InferenceComponentSchedulingConfigBuilder
Creates a new builder-style object to manufacture InferenceComponentSchedulingConfig.