#[non_exhaustive]pub struct TrainingPlanExtension {
pub training_plan_extension_offering_id: Option<String>,
pub extended_at: Option<DateTime>,
pub start_date: Option<DateTime>,
pub end_date: Option<DateTime>,
pub status: Option<String>,
pub payment_status: Option<String>,
pub availability_zone: Option<String>,
pub availability_zone_id: Option<String>,
pub duration_hours: Option<i32>,
pub upfront_fee: Option<String>,
pub currency_code: Option<String>,
}Expand description
Details about an extension to a training plan, including the offering ID, dates, status, and cost information.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.training_plan_extension_offering_id: Option<String>The unique identifier of the extension offering that was used to create this extension.
extended_at: Option<DateTime>The timestamp when the extension was created.
start_date: Option<DateTime>The start date of the extension period.
end_date: Option<DateTime>The end date of the extension period.
status: Option<String>The current status of the extension (e.g., Pending, Active, Scheduled, Failed, Expired).
payment_status: Option<String>The payment processing status of the extension.
availability_zone: Option<String>The Availability Zone of the extension.
availability_zone_id: Option<String>The Availability Zone ID of the extension.
duration_hours: Option<i32>The duration of the extension in hours.
upfront_fee: Option<String>The upfront fee for the extension.
currency_code: Option<String>The currency code for the upfront fee (e.g., USD).
Implementations
Sourceimpl TrainingPlanExtension
impl TrainingPlanExtension
Sourcepub fn training_plan_extension_offering_id(&self) -> Option<&str>
pub fn training_plan_extension_offering_id(&self) -> Option<&str>
The unique identifier of the extension offering that was used to create this extension.
Sourcepub fn extended_at(&self) -> Option<&DateTime>
pub fn extended_at(&self) -> Option<&DateTime>
The timestamp when the extension was created.
Sourcepub fn start_date(&self) -> Option<&DateTime>
pub fn start_date(&self) -> Option<&DateTime>
The start date of the extension period.
Sourcepub fn status(&self) -> Option<&str>
pub fn status(&self) -> Option<&str>
The current status of the extension (e.g., Pending, Active, Scheduled, Failed, Expired).
Sourcepub fn payment_status(&self) -> Option<&str>
pub fn payment_status(&self) -> Option<&str>
The payment processing status of the extension.
Sourcepub fn availability_zone(&self) -> Option<&str>
pub fn availability_zone(&self) -> Option<&str>
The Availability Zone of the extension.
Sourcepub fn availability_zone_id(&self) -> Option<&str>
pub fn availability_zone_id(&self) -> Option<&str>
The Availability Zone ID of the extension.
Sourcepub fn duration_hours(&self) -> Option<i32>
pub fn duration_hours(&self) -> Option<i32>
The duration of the extension in hours.
Sourcepub fn upfront_fee(&self) -> Option<&str>
pub fn upfront_fee(&self) -> Option<&str>
The upfront fee for the extension.
Sourcepub fn currency_code(&self) -> Option<&str>
pub fn currency_code(&self) -> Option<&str>
The currency code for the upfront fee (e.g., USD).
Sourceimpl TrainingPlanExtension
impl TrainingPlanExtension
Sourcepub fn builder() -> TrainingPlanExtensionBuilder
pub fn builder() -> TrainingPlanExtensionBuilder
Creates a new builder-style object to manufacture TrainingPlanExtension.