#[non_exhaustive]pub struct InferenceComponentAvailabilityZoneBalance {
pub enforcement_mode: Option<AvailabilityZoneBalanceEnforcementMode>,
pub max_imbalance: Option<i32>,
}Expand description
Configuration for balancing inference component copies across Availability Zones.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.enforcement_mode: Option<AvailabilityZoneBalanceEnforcementMode>Determines how strictly the Availability Zone balance constraint is enforced.
- PERMISSIVE
-
The endpoint attempts to balance copies across Availability Zones but proceeds with scheduling even if balance can't be achieved due to available capacity or instance distribution across Availability Zones.
max_imbalance: Option<i32>The maximum allowed difference in the number of inference component copies between any two Availability Zones. This parameter applies only when the endpoint has instances across two or more Availability Zones. A copy placement is allowed if it reduces imbalance or the resulting imbalance is within this value.
Default value: 0.
Implementations
Sourceimpl InferenceComponentAvailabilityZoneBalance
impl InferenceComponentAvailabilityZoneBalance
Sourcepub fn enforcement_mode(
&self,
) -> Option<&AvailabilityZoneBalanceEnforcementMode>
pub fn enforcement_mode( &self, ) -> Option<&AvailabilityZoneBalanceEnforcementMode>
Determines how strictly the Availability Zone balance constraint is enforced.
- PERMISSIVE
-
The endpoint attempts to balance copies across Availability Zones but proceeds with scheduling even if balance can't be achieved due to available capacity or instance distribution across Availability Zones.
Sourcepub fn max_imbalance(&self) -> Option<i32>
pub fn max_imbalance(&self) -> Option<i32>
The maximum allowed difference in the number of inference component copies between any two Availability Zones. This parameter applies only when the endpoint has instances across two or more Availability Zones. A copy placement is allowed if it reduces imbalance or the resulting imbalance is within this value.
Default value: 0.
Sourceimpl InferenceComponentAvailabilityZoneBalance
impl InferenceComponentAvailabilityZoneBalance
Sourcepub fn builder() -> InferenceComponentAvailabilityZoneBalanceBuilder
pub fn builder() -> InferenceComponentAvailabilityZoneBalanceBuilder
Creates a new builder-style object to manufacture InferenceComponentAvailabilityZoneBalance.